pub struct DOMLayoutData(AtomicRefCell<InnerDOMLayoutData>);Expand description
A wrapper for InnerDOMLayoutData. This is necessary to give the entire data
structure interior mutability, as we will need to mutate the layout data of
non-mutable DOM nodes.
Tuple Fields
0: AtomicRefCell<InnerDOMLayoutData>Trait Implementations
Sourceimpl Default for DOMLayoutData
impl Default for DOMLayoutData
Sourcefn default() -> DOMLayoutData
fn default() -> DOMLayoutData
Returns the “default value” for a type. Read more
Sourceimpl GenericLayoutDataTrait for DOMLayoutData
impl GenericLayoutDataTrait for DOMLayoutData
fn as_any(&self) -> &dyn Any
Sourcefn set_text_run_selection(
&self,
new_range: Option<RangeAny<Utf32CodeUnits>>,
) -> bool
fn set_text_run_selection( &self, new_range: Option<RangeAny<Utf32CodeUnits>>, ) -> bool
Returns whether
new_range was successfully set on an existing text runSourcefn set_element_selection(&self, selected: bool) -> bool
fn set_element_selection(&self, selected: bool) -> bool
Set whether or not this node is selected when it is an element. Returns
true
if anything changed that requires a new display list.Sourcefn rendered_text(&self, range: RangeAny<Utf32CodeUnits>) -> Option<String>
fn rendered_text(&self, range: RangeAny<Utf32CodeUnits>) -> Option<String>
Get the text rendered by this node, if it is a
CharacterData node and produces
a TextRun in the box tree.Sourceimpl MallocSizeOf for DOMLayoutData
impl MallocSizeOf for DOMLayoutData
Sourcefn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
fn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.
impl LayoutDataTrait for DOMLayoutData